VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsUIVFilt"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "The filter class."
Option Explicit
'This DLL allows you to write an external filter for UI-View32.
'Every frame that UI-VIew32 recognises as a valid APRS frame is
'passed to UIVFilter(), if the function returns True then UI-View32
'carries on processing the frame, otherwise the frame is droppwed.
'
'This is the source code of the version of UIFILT32.DLL supplied
'with UI-View32, it does nothing other than return True for every
'frame.
'
'You MUST maintain binary compatibility with the compiled DLL
'contained in the ZIP.
'
'Filter parameters can be hard coded, or loaded from an external
'file - see LoadFilterParams(). It's entirely up to you what
'you put in the filter, how the parameters are specified and used,
'etc.
'
'For anything other than a simple filter, I would recommend that
'you supply some sort of configuration utility that can be run as
'an Extra from the UI-View32 File menu.
'
'NOTE - you may need to tell the users of your filter to disable
'some aspects of UI-View's internal filtering that are controlled
'from the Excluded List. The internal filtering is applied before
'the external filter is called.
'
'A second copy of UIFILT32.DLL is included in the UI-View32 distribution,
'it is called UIFILT32.ORG. You should tell users that they can remove
'your filter simply by copying UIFILT32.ORG to UIFILT32.DLL.

'The source of the frame.
Const SOURCE_RADIO = 0
Const SOURCE_INET = 1
'LocalNet is the UI-View local server.
Const SOURCE_LOCALNET = 2

'Frame types.
'This list will grow in the future, because some
'APRS frame types are not yet supported.
Const TYPE_UIVIEW_MESS = 1
Const TYPE_APRS_MESS = 2
Const TYPE_STATUS = 3
Const TYPE_MIC_E = 4
Const TYPE_STATION_BEACON = 5
Const TYPE_LOCATOR_BEACON = 6
Const TYPE_NMEA_BEACON = 7
Const TYPE_GLOBAL_QUERY = 8
Const TYPE_WX_QUERY = 9
Const TYPE_OBJECT = 10

Private WithEvents mfrmFilt As frmFilt
Attribute mfrmFilt.VB_VarHelpID = -1

'This procedure is called when the class is initialized, and then
'at the interval set in Class_Initialize().
Private Sub LoadFilterParams()
Static varLastFileDateTime As Variant
Dim varCurrentFileDateTime As Variant
Dim strFname As String
Dim intFd As Integer

'REMOVE THIS EXIT SUB!
Exit Sub

On Error GoTo LoadFilterParamsErr

'You may wish to use a different parameter file name
'to avoid the possibility of loading parameters from
'someone else's version of the filter.
strFname = App.Path & "\UIFILT32.DAT"
If Dir$(strFname) = "" Then Exit Sub

'Check if the parameter file has been changed. This allows
'automatic reloading if the parameters are updated.
'Note - on the first call of this procedure when the class
'is initialized, the last date/time will be 0, and so the
'params will be loaded.
varCurrentFileDateTime = FileDateTime(strFname)
If varLastFileDateTime = varCurrentFileDateTime Then Exit Sub

'Keep a record of the current file date/time.
varLastFileDateTime = varCurrentFileDateTime

'Load your params.
intFd = FreeFile
Open strFname For Binary As intFd
'Load the parameters...

LoadFilterParamsErr:
If intFd <> 0 Then Close intFd
Exit Sub

End Sub

'Every frame that UI-View32 recognises a a valid UI-View/APRS frame
'is passed to this function. Return True for UI-View32 to carry on
'processing the frame, False for it to drop the frame.
'
'strHeader       - the frame header. If the frame was originally in
'                  third party format, then this is the logical header,
'                  because third party frames are rationalized before
'                  this function is called.
'strData         - the information field.
'strFromCallsign - the orignator's callsign.
'strToCallsign   - the destination address.
'intSource       - the source of the frame. See the Declaration section
'                  for constants.
'intFrameType    - the type of frame. See the Declaration section
'                  for constants.
'blnThirdParty   - True if the frame was originally in third party
'                  format.
'blnDirect       - True if the frame was heard direct.
Public Function UIVFilter(strHeader As String, strData As String, _
        strFromCallsign As String, strToCallsign As String, _
        intSource As Integer, intFrameType As Integer, _
        blnThirdParty As Boolean, blnDirect As Boolean) As Boolean
Attribute UIVFilter.VB_Description = "The filter fumction. See the comments in the source code."

'Do your stuff here... All I'm doing is always returning True.
'Don't put in too much code! You might have an impact on performance
'when data is arriving very quickly on an internet connection.
UIVFilter = True

End Function

Private Sub Class_Initialize()

LoadFilterParams

Set mfrmFilt = New frmFilt
'Every time the Timer fires, LoadFilterParams() is called
'via mfrmFilt_TimerEvemt(). If you really want to check more
'frequently for changed params, then reduce the Timer interval.
mfrmFilt.Timer1.Interval = 30000
mfrmFilt.Timer1.Enabled = True

End Sub

Private Sub Class_Terminate()

mfrmFilt.Timer1.Enabled = False
Set mfrmFilt = Nothing

End Sub

Private Sub mfrmFilt_TimerEvent()

LoadFilterParams

End Sub

